Stan Math Library: stan/math/prim/mat/err/check_cov_matrix.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_cov_matrix.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_ERR_CHECK_COV_MATRIX_HPP
2 #define STAN_MATH_PRIM_MAT_ERR_CHECK_COV_MATRIX_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/err/check_pos_definite.hpp>
6
7 namespace stan {
8 namespace math {
29 template <typename T_y>
30 inline bool
31 check_cov_matrix(
32 const char* function,
33 const char* name,
34 const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y
35 ) {
36 check_pos_definite(function, name, y);
37 return true;
38 }
39
40 }
41 }
42 #endif
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp
stan::math::check_cov_matrix
bool check_cov_matrix(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is a valid covariance matrix.
Definition: check_cov_matrix.hpp:31
stan::math::check_pos_definite
bool check_pos_definite(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified square, symmetric matrix is positive definite.
Definition: check_pos_definite.hpp:37
check_pos_definite.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.